@@ -72,22 +72,6 @@ from univention.admin.certificate import PKIIntegration, register_pki_integratio
 
 from typing import List  # noqa: F401
 
-try:
-	from univention.admin.syntax import ActivationDateTimeTimezone
-except ImportError:
-	# workaround for errors during errata-updates. should be removable with UCS 5.0-1
-	class ActivationDateTimeTimezone(univention.admin.syntax.complex):
-		"""
-		Syntax for YYYY-mm-dd HH:MM TZNAME
-		"""
-		delimiter = ' '
-		subsyntaxes = [('Date', univention.admin.syntax.iso8601Date), ('Time', univention.admin.syntax.TimeString), ('Timezone', univention.admin.syntax.string)]
-		subsyntax_names = ('date', 'time', 'timezone')
-		subsyntax_names = ('activation-date', 'activation-time', 'activation-timezone')
-		size = ('TwoThirds', 'TwoThirds', 'TwoThirds')
-		all_required = False
-		min_elements = 0
-	univention.admin.syntax.ActivationDateTimeTimezone = ActivationDateTimeTimezone
 
 if not six.PY2:
 	long = int
@@ -250,7 +234,7 @@ property_descriptions = {
 		long_description=_('This disables the account until the specified time.'),
 		syntax=univention.admin.syntax.ActivationDateTimeTimezone,
 		dontsearch=True,
-		default=[[None, None, tzlocal.get_localzone().zone], []],
+		default=([None, None, tzlocal.get_localzone().zone], []),
 	),
 	'locked': univention.admin.property(  # This property only serves two purposes: 1) filtering 2) artificial simulation of lockout
 		short_description=_('Locked state of account'),
@@ -346,7 +330,6 @@ property_descriptions = {
 		short_description=_('Employee number'),
 		long_description='',
 		syntax=univention.admin.syntax.string,
-		include_in_default_search=True,
 	),
 	'roomNumber': univention.admin.property(
 		short_description=_('Room number'),
@@ -1158,94 +1141,84 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 			else:
 				self.options.append(opt)
 
+	def _post_unmap(self, info, values):
+		info = super(object, self)._post_unmap(info, values)
+		self._unmap_mail_forward(info, values)
+		self._unmap_pwd_change_next_login(info, values)
+		return info
+
 	def open(self, loadGroups=True):
 		univention.admin.handlers.simpleLdap.open(self)
 		self.pki_open()
 		if self.exists():
-			self._unmap_mail_forward()
-			self._unmap_pwd_change_next_login()
 			self._unmap_automount_information()
 			self._unmapUnlockTime()
 			self._load_groups(loadGroups)
+			self._unmap_gid_number()
 		self.save()
-		if not self.exists():  # TODO: move this block into _ldap_pre_create!
+		# self.save() must not be called after this point in self.open()
+		# otherwise self.__primary_group doesn't add a new user to the
+		# univentionDefaultGroup because "not self.hasChanged('primaryGroup')"
+		if not self.exists():
 			self._set_default_group()
 
 	def _load_groups(self, loadGroups):
-		if self.exists():
-			if loadGroups:  # this is optional because it can take much time on larger installations, default is true
-				self['groups'] = [x.decode('UTF-8') if six.PY2 else x for x in self.lo.searchDn(filter=filter_format(u'(&(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping))(uniqueMember=%s))', [self.dn]))]
-			else:
-				ud.debug(ud.ADMIN, ud.INFO, 'user: open with loadGroups=false for user %s' % self['username'])
-			self.groupsLoaded = loadGroups
-			primaryGroupNumber = self.oldattr.get('gidNumber', [b''])[0].decode('ASCII')
-			if primaryGroupNumber:
-				primary_group = get_primary_group_dn(self.lo, primaryGroupNumber)
-				if primary_group:
-					self['primaryGroup'] = primary_group
-				else:
-					try:
-						primaryGroup = self.lo.search(filter='(objectClass=univentionDefault)', base='cn=univention,' + self.position.getDomain(), attr=['univentionDefaultGroup'])
-						try:
-							primaryGroup = primaryGroup[0][1]["univentionDefaultGroup"][0].decode('UTF-8')
-						except Exception:
-							primaryGroup = None
-					except Exception:
-						primaryGroup = None
+		if loadGroups:  # this is optional because it can take much time on larger installations, default is true
+			self['groups'] = [x.decode('UTF-8') if six.PY2 else x for x in self.lo.searchDn(filter=filter_format(u'(&(|(objectClass=univentionGroup)(objectClass=sambaGroupMapping))(uniqueMember=%s))', [self.dn]))]
+		else:  # TODO: document where it is needed and used
+			ud.debug(ud.ADMIN, ud.INFO, 'user: open with loadGroups=false for user %s' % (self['username'],))
+		self.groupsLoaded = loadGroups
 
-					ud.debug(ud.ADMIN, ud.INFO, 'user: could not find primaryGroup, setting primaryGroup to %s' % primaryGroup)
+	def _unmap_gid_number(self):
+		primaryGroupNumber = self.oldattr.get('gidNumber', [b''])[0].decode('ASCII')
+		if not primaryGroupNumber:
+			self.info['primaryGroup'] = None
+			self.save()
+			raise univention.admin.uexceptions.primaryGroup(self.dn)
 
-					if not primaryGroup:
-						raise univention.admin.uexceptions.primaryGroup(self.dn)
-					self.info['primaryGroup'] = primaryGroup
-					self.__primary_group()
-			else:
-				self.info['primaryGroup'] = None
-				self.save()
-				raise univention.admin.uexceptions.primaryGroup(self.dn)
+		primary_group = get_primary_group_dn(self.lo, primaryGroupNumber)
+		if primary_group:
+			self['primaryGroup'] = primary_group
+			return
+
+		ud.debug(ud.ADMIN, ud.ERROR, 'No primary group was found with gidNumber=%s for %s as %s' % (primaryGroupNumber, self.dn, self.lo.binddn))
 
 	def _set_default_group(self):
-		primary_group_from_template = self['primaryGroup']
-		if not primary_group_from_template:
-			searchResult = self.lo.search(filter=u'(objectClass=univentionDefault)', base=u'cn=univention,' + self.position.getDomain(), attr=['univentionDefaultGroup'])
-			if not searchResult or not searchResult[0][1]:
-				self.info['primaryGroup'] = None
-				self.save()
-				raise univention.admin.uexceptions.primaryGroup(self.dn)
+		if not self['primaryGroup']:
+			for _dn, attrs in self.lo.search(filter='(objectClass=univentionDefault)', base=u'cn=univention,' + self.position.getDomain(), attr=['univentionDefaultGroup']):
+				primary_group = attrs['univentionDefaultGroup'][0].decode('UTF-8')
+				ud.debug(ud.ADMIN, ud.INFO, 'user: setting primaryGroup to %s' % (primary_group,))
+				if self.lo.get(primary_group):
+					self['primaryGroup'] = primary_group
 
-			for tmp, number in searchResult:
-				primaryGroupResult = self.lo.searchDn(filter=filter_format(u'(&(objectClass=posixGroup)(cn=%s))', (univention.admin.uldap.explodeDn(number['univentionDefaultGroup'][0].decode('UTF-8'), 1)[0],)), base=self.position.getDomain(), scope='domain')
-				if primaryGroupResult:
-					self['primaryGroup'] = primaryGroupResult[0]
-					# self.save() must not be called after this point in self.open()
-					# otherwise self.__primary_group doesn't add a new user to the
-					# univentionDefaultGroup because "not self.hasChanged('primaryGroup')"
+		if not self['primaryGroup']:
+			raise univention.admin.uexceptions.primaryGroup(self.dn)
 
-	def _unmap_pwd_change_next_login(self):
-		self['pwdChangeNextLogin'] = '0'
-		if self.oldattr.get('shadowLastChange', [b''])[0] == b'0':
-			self['pwdChangeNextLogin'] = '1'
-		elif self['passwordexpiry']:
+	def _unmap_pwd_change_next_login(self, info, oldattr):
+		info['pwdChangeNextLogin'] = '0'
+		if oldattr.get('shadowLastChange', [b''])[0] == b'0':
+			info['pwdChangeNextLogin'] = '1'
+		elif info['passwordexpiry']:
 			today = time.strftime('%Y-%m-%d').split('-')
-			expiry = self['passwordexpiry'].split('-')
+			expiry = info['passwordexpiry'].split('-')
 			# expiry.reverse()
 			# today.reverse()
 			if int(''.join(today)) >= int(''.join(expiry)):
-				self['pwdChangeNextLogin'] = '1'
+				info['pwdChangeNextLogin'] = '1'
 
-	def _unmap_mail_forward(self):
+	def _unmap_mail_forward(self, info, oldattr):
 		if configRegistry.is_true('directory/manager/user/activate_ldap_attribute_mailForwardCopyToSelf', False):
 			return
 		# mailForwardCopyToSelf is a "virtual" property. The boolean value is set to True, if
 		# the LDAP attribute mailForwardAddress contains the mailPrimaryAddress. The mailPrimaryAddress
 		# is removed from oldattr for correct display in CLI/UMC and for proper detection of changes.
 		# Remark: By setting the ucr-v the attribute is saved directly to LDAP.
-		if self.get('mailPrimaryAddress') in self.get('mailForwardAddress', []):
-			self.oldattr['mailForwardAddress'] = self.oldattr.get('mailForwardAddress', [])[:]
-			self['mailForwardAddress'].remove(self['mailPrimaryAddress'])
-			self['mailForwardCopyToSelf'] = '1'
+		if info.get('mailPrimaryAddress') in info.get('mailForwardAddress', []):
+			oldattr['mailForwardAddress'] = oldattr.get('mailForwardAddress', [])[:]
+			info['mailForwardAddress'].remove(info['mailPrimaryAddress'])
+			info['mailForwardCopyToSelf'] = '1'
 		else:
-			self['mailForwardCopyToSelf'] = '0'
+			info['mailForwardCopyToSelf'] = '0'
 
 	def _unmap_automount_information(self):
 		if 'automountInformation' not in self.oldattr:
@@ -1465,6 +1438,7 @@ class object(univention.admin.handlers.simpleLdap, PKIIntegration):
 			self.info['password'] = self.oldinfo['password'] = u'*'
 			self.info['disabled'] = self.oldinfo['disabled']
 
+		self._set_default_group()
 		if not self.exists() or self.hasChanged('primaryGroup'):
 			# Ensure the primary Group has the samba option enabled
 			if self['primaryGroup'] and not self.lo.getAttr(self['primaryGroup'], 'sambaSID'):
